AuthenticationProvider class abstract

Implement to provide authentication logic (e.g., validate JWT, check credentials). Boot discovers all AuthenticationProvider beans and tries them in order.

Constructors

AuthenticationProvider()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

authenticate(AuthenticationRequest request) Future<Authentication?>
Attempt to authenticate the request. Return an Authentication on success, null on failure.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited