HttpClientConfiguration class

Configuration for the HTTP client, read from boot.http.client.* in application.yml.

boot:
  http:
    client:
      connect-timeout: 5s
      read-timeout: 30s
      max-redirects: 5

Constructors

HttpClientConfiguration({Duration connectTimeout = const Duration(seconds: 5), Duration readTimeout = const Duration(seconds: 30), int maxRedirects = 5})
HttpClientConfiguration.fromConfig(BootConfig config)
Create from BootConfig (reads boot.http.client.* properties).
factory

Properties

connectTimeout Duration
final
hashCode int
The hash code for this object.
no setterinherited
maxRedirects int
final
readTimeout Duration
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited