Named class

Qualifier that identifies a bean by name.

If value is omitted, it is derived from the class name: ReadOnlyPool'readOnlyPool', DiskCache'diskCache'.

Constructors

Named([String? value])
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited