NonUniqueBeanException class

Thrown when multiple beans match an injection point with no qualifier or @Primary.

Implemented types

Constructors

NonUniqueBeanException(Type type, List<String> candidates)

Properties

candidates List<String>
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type Type
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited