RequestLoggingFilter class

Built-in filter that logs every HTTP request with method, path, status, and duration.

Implemented types

Constructors

RequestLoggingFilter()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

filter(Request request, FilterChain chain) Future<Response>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited