Scheduled class

Schedules a method for periodic or delayed execution.

Exactly one of fixedRate, fixedDelay, or cron must be specified.

Annotations

Constructors

Scheduled({String? fixedRate, String? fixedDelay, String? cron, String? initialDelay})
const

Properties

cron String?
Cron expression (e.g., '0 */5 * * *' for every 5 minutes).
final
fixedDelay String?
Execute with a fixed delay between completions (e.g., '10s').
final
fixedRate String?
Execute at a fixed rate (e.g., '5s', '1m', '500ms').
final
hashCode int
The hash code for this object.
no setterinherited
initialDelay String?
Initial delay before first execution (e.g., '2s').
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited