ServerFilter class
Annotation for server-side HTTP filters. Apply to a class that implements HttpServerFilter.
- Annotations
-
- @BeanSource()
Constructors
-
ServerFilter({String pattern = '/**', List<
String> methods = const []}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
methods
→ List<
String> -
HTTP methods to filter (empty = all methods).
final
- pattern → String
-
URL pattern to match (ant-style: /api/, /users/*). Defaults to '/' (all).
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited