BeanDefinition class abstract
Compile-time generated bean definition.
Constructors
Properties
-
annotationMetadata
→ List<
AnnotationValue> -
All annotations on this bean, resolved at compile time.
no setter
- beanType → Type
-
The bean's runtime type.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasPostConstruct → bool
-
no setter
- hasPostConstructAsync → bool
-
no setter
- hasPreDestroy → bool
-
no setter
- hasPreDestroyAsync → bool
-
no setter
-
methodMetadata
→ List<
MethodMetadata> -
Annotated methods on this bean (for @EventListener, @Scheduled, etc.)
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
create(
BeanContainer container) → dynamic - Create the bean instance, resolving dependencies from the container.
-
dispatch(
Object instance, String method, List args) → dynamic - Dispatch a method call on the bean instance without reflection.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
postConstruct(
dynamic instance) → void -
postConstructAsync(
dynamic instance) → Future< void> -
preDestroy(
dynamic instance) → void -
preDestroyAsync(
dynamic instance) → Future< void> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited